==> haskell-http-streams-0.8.6.1-30-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-J0dFnpLyqsARxRWlgwRKW
key: http-streams-0.8.6.1-J0dFnpLyqsARxRWlgwRKW
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: 80f65dde03107f4c04cdbcbf37bc9542
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-J0dFnpLyqsARxRWlgwRKW
depends:
    attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq base-4.11.1.0
    directory-1.3.1.5 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    io-streams-1.5.0.1-3kE2l2s5RqhB8LMNmX4WMU
    HsOpenSSL-0.11.4.14-Ivgxm6d4ti135ieN9wCA5m
    openssl-streams-1.2.1.3-KBd6GiygmO8LfjxYEKZdAQ mtl-2.2.2
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf
    http-common-0.8.2.0-KlbGkT8cQDp1PalZKO9RLV
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v
abi-depends: attoparsec-0.13.2.2-4pZqFyZuvv0DMBnjRhBKkq=07053c5359c7530f0cb8534ff020b021
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             io-streams-1.5.0.1-3kE2l2s5RqhB8LMNmX4WMU=4aeb39371d7edd673022d6079fe1a91d
             HsOpenSSL-0.11.4.14-Ivgxm6d4ti135ieN9wCA5m=6f0fd119536ea9ab19f183db7d4171f1
             openssl-streams-1.2.1.3-KBd6GiygmO8LfjxYEKZdAQ=d8bb81605627951d3ffcece5a5dceaea
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             aeson-1.3.1.1-EBUC8UHBskq8l6BMagWOXf=099629a1e097a2a1a4c1ce1f1c4a7711
             http-common-0.8.2.0-KlbGkT8cQDp1PalZKO9RLV=e3fb1f7554aff2945c195d0979982556
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             network-2.7.0.1-4JbsvGgupC8D8OEac3vD1v=9f1a3e2a2d1ba200f0b4b28f3589f138
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-streams-0.8.6.1-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-streams.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-streams
version: 0.8.6.1
id: http-streams-0.8.6.1-C6F8Q5kJi9HJAKqNwylnkW
key: http-streams-0.8.6.1-C6F8Q5kJi9HJAKqNwylnkW
license: BSD-3-Clause
copyright: © 2012-2018 Operational Dynamics Consulting, Pty Ltd and Others
maintainer: Andrew Cowie <andrew@operationaldynamics.com>
author: Andrew Cowie <andrew@operationaldynamics.com>
stability: experimental
homepage: https://github.com/afcowie/http-streams/
synopsis: An HTTP client using io-streams
description:
    /Overview/
    .
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.
    .
    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.
category: Web, IO-Streams
abi: c7fea588f2dced1bdc13cf83d72bbcc9
exposed: True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser
hidden-modules: Network.Http.Utilities
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-streams-0.8.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/http-streams-0.8.6.1
hs-libraries: HShttp-streams-0.8.6.1-C6F8Q5kJi9HJAKqNwylnkW
depends:
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ base-4.11.1.0
    directory-1.3.1.5 base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    io-streams-1.5.0.1-GYTv26BuJtI7y8Q4k3saRq
    HsOpenSSL-0.11.4.14-7OllUDAspc1HeRlFq6UPNM
    openssl-streams-1.2.1.3-Bd2V8zQjIpPAimqXvcL6i3 mtl-2.2.2
    transformers-0.5.5.0 text-1.2.3.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
    aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y
    http-common-0.8.2.0-ArwORgdjzaUBimhan937zs
    network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
    network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr
abi-depends: attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             base64-bytestring-1.0.0.1-4OCIe2BZn8jKI191JIXI37=6373b2ec1ae2585bcca6cddbee5d3e75
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=bcd8ba72b672d042505b8fc55f637c88
             io-streams-1.5.0.1-GYTv26BuJtI7y8Q4k3saRq=8fc19154263de72dbf0f48adccedbd46
             HsOpenSSL-0.11.4.14-7OllUDAspc1HeRlFq6UPNM=efe564c2e7e05152ec71d328c701362f
             openssl-streams-1.2.1.3-Bd2V8zQjIpPAimqXvcL6i3=955a097777ab336e99d5eb5eaf0e5cc1
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
             aeson-1.3.1.1-TT45dpTFlI3IDS4gOrl3y=07d229e9fe1ca7309e20349a237239ed
             http-common-0.8.2.0-ArwORgdjzaUBimhan937zs=65c2c882cf3e87d36a5e5eee1356daf3
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=1c5b19d707f7ce4714ffa81cd536dbf4
             network-2.7.0.1-BCOaRvxEBr5QkpBn67mFr=64a54c687aa7806d1b651ff4086a22e3
haddock-interfaces: /usr/share/doc/haskell-http-streams/html/http-streams.haddock
haddock-html: /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
